"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.highlightMiddleware = void 0;
const node_1 = require("@highlight-run/node");
const factory_1 = require("hono/factory");
/**
 * Creates a Hono middleware that automatically traces requests and reports errors to Highlight
 */
const highlightMiddleware = (options) => {
    if (!node_1.H.isInitialized()) {
        node_1.H.init(options);
    }
    return (0, factory_1.createMiddleware)(async (c, next) => {
        const spanName = `${c.req.method} ${c.req.path}`;
        const headers = c.req.header();
        // Run the request handler with Highlight tracing
        await node_1.H.runWithHeaders(spanName, headers, async () => {
            try {
                await next();
            }
            finally {
                if (c.error) {
                    node_1.H.consumeError(c.error);
                }
            }
        }, {
            attributes: {
                'http.method': c.req.method,
                'http.route': c.req.path,
                'http.url': c.req.url,
            },
        });
    });
};
exports.highlightMiddleware = highlightMiddleware;
