"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const node_1 = require("@highlight-run/node");
const index_1 = require("./index");
const hono_1 = require("hono");
const testing_1 = require("hono/testing");
// Mock @highlight-run/node
vitest_1.vi.mock('@highlight-run/node', () => ({
    H: {
        init: vitest_1.vi.fn(),
        isInitialized: vitest_1.vi.fn(),
        runWithHeaders: vitest_1.vi.fn(),
        consumeError: vitest_1.vi.fn(),
    },
}));
const mockOptions = { projectID: 'test-project' };
const getTestClient = (options = mockOptions) => {
    return (0, testing_1.testClient)(new hono_1.Hono()
        .use((0, index_1.highlightMiddleware)(options))
        .get('/search', (c) => c.text('Hello, World!'))
        .get('/error', (c) => {
        throw new Error('Test error');
        return c.text('ERROR!');
    }));
};
let mockHighlightInstance;
(0, vitest_1.describe)('highlightMiddleware', () => {
    (0, vitest_1.beforeEach)(() => {
        vitest_1.vi.clearAllMocks();
        vitest_1.vi.mocked(node_1.H.isInitialized).mockReturnValue(false);
        vitest_1.vi.mocked(node_1.H.init).mockReturnValue({});
        vitest_1.vi.mocked(node_1.H.runWithHeaders).mockImplementation(async (_, __, fn) => await fn({}));
        vitest_1.vi.mocked(node_1.H.consumeError).mockImplementation((error, _, __) => { });
    });
    (0, vitest_1.it)('should initialize Highlight when not already initialized', async () => {
        const response = await getTestClient().search.$get();
        (0, vitest_1.expect)(node_1.H.init).toHaveBeenCalledWith(mockOptions);
        (0, vitest_1.expect)(response.status).toBe(200);
    });
    (0, vitest_1.it)('should not initialize Highlight when already initialized', async () => {
        vitest_1.vi.mocked(node_1.H.isInitialized).mockReturnValue(true);
        const response = await getTestClient().search.$get();
        (0, vitest_1.expect)(node_1.H.init).not.toHaveBeenCalled();
        (0, vitest_1.expect)(response.status).toBe(200);
    });
    (0, vitest_1.it)('should trace requests with correct attributes', async () => {
        const response = await getTestClient().search.$get();
        (0, vitest_1.expect)(node_1.H.runWithHeaders).toHaveBeenCalledWith('GET /search', {}, vitest_1.expect.any(Function), {
            attributes: {
                'http.method': 'GET',
                'http.route': '/search',
                'http.url': 'http://localhost/search',
            },
        });
        (0, vitest_1.expect)(response.status).toBe(200);
    });
    (0, vitest_1.it)('handles errors and reports them', async () => {
        const response = await getTestClient().error.$get();
        (0, vitest_1.expect)(node_1.H.consumeError).toHaveBeenCalled();
        (0, vitest_1.expect)(response.status).toBe(500);
    });
});
